@@ -5,7 +5,7 @@ from tensorflow.keras import layers,activations
 from tensorflow.keras.callbacks import EarlyStopping
 from tensorflow.keras.callbacks import ModelCheckpoint
 
-SE模块
+#SE模块
 #如需使用，得加到下采样层里
 class Squeeze_excitation_layer(tf.keras.Model):
     def __init__(self, filter_sq):
